@@ -17,12 +17,11 @@ from typing import Tuple, List, Dict, Any, Optional, Union, Type
 import numpy as np
 import numpy.typing as npt
 
+from amarium.checks import check_make_file_name_suffix, check_make_dir
+
 LOGGER = logging.getLogger(__name__)
 
 
-timestr = time.strftime("%Y%m%d-%H%M%S")
-
-
 def prepare_file_name_saving(prefix: str, file_name: str, suffix: str) -> str:
     """The prepare_file_name_saving function takes a prefix and file name as
     input. It checks to see if the directory exists, and makes it if not. Then
@@ -36,7 +35,7 @@ def prepare_file_name_saving(prefix: str, file_name: str, suffix: str) -> str:
     """
     check_make_dir(prefix)
     file_name = make_full_filename(prefix, file_name)
-    file_name = check_file_name(file_name, suffix)
+    file_name = check_make_file_name_suffix(file_name, suffix)
     return file_name
 
 
@@ -74,25 +73,6 @@ def insert_string_in_file_name(file_name: str, insertion: str, suffix: str) -> s
     return file_name
 
 
-def check_file_name(file_name: str, suffix: str) -> str:
-    """The check_name_plot function checks that the file_name ends with .png.
-    If it does not, then check_name_plot appends .png to the end of the
-    file_name.
-
-    :param file_name: Used to Specify the name of the file to be plotted.
-    :return: The file_name with the correct file extension.
-
-    :doc-author: Trelent
-    """
-    name = file_name
-    ext = os.path.splitext(file_name)[1]
-    if not ext:
-        if not suffix.startswith("."):
-            suffix = "." + suffix
-        name += suffix
-    return name
-
-
 def make_full_filename(prefix: str, file_name: str) -> str:
     """
     The make_full_filename function takes a prefix and a file_name as input.
@@ -118,28 +98,6 @@ def make_full_filename(prefix: str, file_name: str) -> str:
     return file_name
 
 
-def check_make_dir(dir_name: str) -> None:
-    """The check_make_dir function checks if a directory exists. If it does not
-    exist, the function creates it.
-
-    :param dir_name:str: Used to Specify the folder name.
-    :return: None.
-
-    :doc-author: Trelent
-    """
-
-    # You should change 'test' to your preferred folder.
-    check_folder = os.path.isdir(dir_name)
-    logging.info("Checked the directory %s", dir_name)
-    # If folder doesn't exist, then create it.
-    if not check_folder:
-        os.makedirs(dir_name)
-        logging.info("Created folder : %s", dir_name)
-
-    else:
-        logging.info("%s folder already exists.", dir_name)
-
-
 def load_json_from_file(file_name: str) -> Dict[Any, Any]:
     """
     The load_json_from_file function takes a file name as input and returns the contents of that
